"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createAlchemyPublicRpcClient = void 0;
const aa_core_1 = require("@alchemy/aa-core");
const viem_1 = require("viem");
const schema_js_1 = require("../schema.js");
const version_js_1 = require("../version.js");
const createAlchemyPublicRpcClient = ({ chain: chain_, connectionConfig, fetchOptions = {}, }) => {
    const chain = schema_js_1.AlchemyChainSchema.parse(chain_);
    const rpcUrl = connectionConfig.rpcUrl == null
        ? `${chain.rpcUrls.alchemy.http[0]}/${connectionConfig.apiKey ?? ""}`
        : connectionConfig.rpcUrl;
    fetchOptions.headers = {
        ...fetchOptions.headers,
        "Alchemy-AA-Sdk-Version": version_js_1.VERSION,
    };
    if (connectionConfig.jwt != null) {
        fetchOptions.headers = {
            ...fetchOptions.headers,
            Authorization: `Bearer ${connectionConfig.jwt}`,
        };
    }
    return (0, aa_core_1.createBundlerClient)({
        chain: chain,
        transport: (0, viem_1.http)(rpcUrl, { fetchOptions }),
    }).extend(() => ({
        updateHeaders(newHeaders) {
            fetchOptions.headers = {
                ...fetchOptions.headers,
                ...newHeaders,
            };
        },
    }));
};
exports.createAlchemyPublicRpcClient = createAlchemyPublicRpcClient;
//# sourceMappingURL=rpcClient.js.map