"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.reconnect = void 0;
const client_js_1 = require("../store/client.js");
const createAccount_js_1 = require("./createAccount.js");
const getChain_js_1 = require("./getChain.js");
async function reconnect(config) {
    const { clientStore } = config;
    const signerConfig = clientStore.getState().config;
    const accountConfigs = clientStore.getState().accountConfigs;
    const signer = (0, client_js_1.createSigner)(signerConfig);
    const chain = (0, getChain_js_1.getChain)(config);
    clientStore.setState({
        signer,
    });
    const unsubConnected = signer.on("connected", async () => {
        if (accountConfigs[chain.id]?.["LightAccount"]) {
            await (0, createAccount_js_1.createAccount)({
                type: "LightAccount",
                accountParams: accountConfigs[chain.id]["LightAccount"],
            }, config);
        }
        if (accountConfigs[chain.id]?.["MultiOwnerModularAccount"]) {
            await (0, createAccount_js_1.createAccount)({
                type: "MultiOwnerModularAccount",
                accountParams: accountConfigs[chain.id]["MultiOwnerModularAccount"],
            }, config);
        }
        unsubConnected();
    });
    const unsubDisconnected = signer.on("disconnected", () => {
        clientStore.setState({
            accountConfigs: {},
        });
        unsubDisconnected();
    });
}
exports.reconnect = reconnect;
//# sourceMappingURL=reconnect.js.map