"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useClientActions = void 0;
const react_query_1 = require("@tanstack/react-query");
const react_1 = require("react");
const errors_js_1 = require("../errors.js");
function useClientActions(args) {
    const { client, actions } = args;
    const { mutate, isPending: isExecutingAction, error, mutateAsync, data, } = (0, react_query_1.useMutation)({
        mutationFn: async ({ functionName, args, }) => {
            if (!client) {
                throw new errors_js_1.ClientUndefinedHookError("useClientActions");
            }
            const actions_ = actions(client);
            return actions_[functionName](...args);
        },
    });
    const executeAction = (0, react_1.useCallback)((params) => {
        const { functionName, args } = params;
        return mutate({ functionName, args });
    }, [mutate]);
    const executeActionAsync = (0, react_1.useCallback)(async (params) => {
        const { functionName, args } = params;
        return mutateAsync({ functionName, args });
    }, [mutateAsync]);
    return {
        executeAction,
        executeActionAsync,
        data,
        isExecutingAction,
        error,
    };
}
exports.useClientActions = useClientActions;
//# sourceMappingURL=useClientActions.js.map