import { BaseError } from "../errors/base.js";
/**
 * Error thrown when a hook is called without a AlchemyAccountProvider.
 *
 * @param hookName The name of the hook.
 */
export declare class NoAlchemyAccountContextError extends BaseError {
    constructor(hookName: string);
}
/**
 * Error thrown when a hook is called without a client.
 *
 * @param hookName The name of the hook.
 */
export declare class ClientUndefinedHookError extends BaseError {
    constructor(hookName: string);
}
/**
 * An error thrown by hooks that require a uiConfig to be supplied to the AlchemyAccountProvider.
 */
export declare class MissingUiConfigError extends BaseError {
    /**
     * @param hookName the name of the hook that is throwing this error
     */
    constructor(hookName: string);
}
/**
 * An error thrown when connected to an EOA and trying to execute an action that is not supported.
 */
export declare class UnsupportedEOAActionError extends BaseError {
    /**
     * @param hookName the hook that threw the error
     * @param action the action not supported by an EOA
     */
    constructor(hookName: string, action: string);
}
//# sourceMappingURL=errors.d.ts.map