import { type UseMutateFunction } from "@tanstack/react-query";
import { type CSSProperties } from "react";
import type { ExportWalletParams as ExportAccountParams } from "../../index.js";
import type { BaseHookMutationArgs } from "../types.js";
export type UseExportAccountMutationArgs = {
    params?: ExportAccountParams;
} & BaseHookMutationArgs<boolean, void>;
/**
 * Props for the `ExportAccountComponent` component. This component is
 * returned from the `useExportAccount` hook and should be rendered in the
 * parent component to display the account recovery details in an iframe.
 *
 * iframeCss [optional] - CSS to apply to the iframe.
 *
 * className [optional] - Class name to apply to the container div.
 *
 * isExported - Whether the account has been exported.
 */
export type ExportAccountComponentProps = {
    iframeCss?: CSSProperties;
    className?: string;
    isExported: boolean;
};
export type UseExportAccountResult = {
    exportAccount: UseMutateFunction<boolean, Error, void, unknown>;
    isExported: boolean;
    isExporting: boolean;
    error: Error | null;
    ExportAccountComponent: (props: ExportAccountComponentProps) => JSX.Element;
};
export declare function useExportAccount(args?: UseExportAccountMutationArgs): UseExportAccountResult;
//# sourceMappingURL=useExportAccount.d.ts.map