import type { EntryPointVersion, GetEntryPointFromAccount, SendUserOperationParameters, SendUserOperationResult } from "@alchemy/aa-core";
import { type UseMutateAsyncFunction, type UseMutateFunction } from "@tanstack/react-query";
import type { Hex } from "viem";
import type { SupportedAccounts } from "../../config/types.js";
import type { BaseHookMutationArgs } from "../types.js";
import { type UseSmartAccountClientResult } from "./useSmartAccountClient.js";
export type SendUserOperationWithEOA<TEntryPointVersion extends EntryPointVersion> = SendUserOperationResult<TEntryPointVersion> | {
    hash: Hex;
    request?: never;
};
export type UseSendUserOperationMutationArgs<TEntryPointVersion extends GetEntryPointFromAccount<TAccount>, TAccount extends SupportedAccounts = SupportedAccounts> = BaseHookMutationArgs<SendUserOperationWithEOA<TEntryPointVersion>, SendUserOperationParameters<TAccount>>;
export type UseSendUserOperationArgs<TEntryPointVersion extends GetEntryPointFromAccount<TAccount>, TAccount extends SupportedAccounts = SupportedAccounts> = {
    client: UseSmartAccountClientResult["client"] | undefined;
    waitForTxn?: boolean;
} & UseSendUserOperationMutationArgs<TEntryPointVersion, TAccount>;
export type UseSendUserOperationResult<TEntryPointVersion extends GetEntryPointFromAccount<TAccount>, TAccount extends SupportedAccounts = SupportedAccounts> = {
    sendUserOperation: UseMutateFunction<SendUserOperationWithEOA<TEntryPointVersion>, Error, SendUserOperationParameters<TAccount>, unknown>;
    sendUserOperationAsync: UseMutateAsyncFunction<SendUserOperationWithEOA<TEntryPointVersion>, Error, SendUserOperationParameters<TAccount>, unknown>;
    sendUserOperationResult: SendUserOperationWithEOA<TEntryPointVersion> | undefined;
    isSendingUserOperation: boolean;
    error: Error | null;
};
/**
 * A hook that returns functions for sending user operations.
 * You can also optionally wait for a user operation to be mined before returning.
 *
 * @param params the parameters for the hook including the client, a flag to wait for tx mining, and mutation args (see {@link UseSendUserOperationArgs})
 * @returns functions and state for sending UOs {@link UseSendUserOperationResult}
 */
export declare function useSendUserOperation<TEntryPointVersion extends GetEntryPointFromAccount<TAccount>, TAccount extends SupportedAccounts = SupportedAccounts>(params: UseSendUserOperationArgs<TEntryPointVersion, TAccount>): UseSendUserOperationResult<TEntryPointVersion, TAccount>;
//# sourceMappingURL=useSendUserOperation.d.ts.map