import type { AccountKitThemeColor, ColorVariantRecord, DeepPartial } from "./types";
/**
 * Creates a color object to be used within account kit utilities, components, and themes
 *
 * @param light the light mode color value
 * @param dark the dark mode color value
 * @returns the color set object
 */
export declare const createColorSet: (light: string, dark: string) => ColorVariantRecord;
/**
 * Overwrites the values in S with values in T if they exist
 *
 * @param source the source object to replace values with those from target
 * @param target the target object to use as a source of truth
 * @returns the deeply merged object of S and T
 */
export declare const apply: <S extends Record<string, any>>(source: S, target?: DeepPartial<S> | undefined) => S;
/**
 * Given an Account Kit theme color name, returns the css variable name
 *
 * @param name one of the Account Kit theme color names
 * @returns the css variable name
 */
export declare const getColorVariableName: (name: AccountKitThemeColor) => string;
//# sourceMappingURL=utils.d.ts.map